@@ -23,7 +23,7 @@
 int alfred_client_request_data(struct globals *globals)
 {
 	unsigned char buf[MAX_PAYLOAD], *pos;
-	struct alfred_request_v0 *request;
+	struct alfred_request_v0 request;
 	struct alfred_push_data_v0 *push;
 	struct alfred_status_v0 *status;
 	struct alfred_tlv *tlv;
@@ -34,17 +34,15 @@ int alfred_client_request_data(struct globals *globals)
 	if (unix_sock_open_client(globals))
 		return -1;
 
-	request = (struct alfred_request_v0 *)buf;
-	len = sizeof(*request);
+	len = sizeof(request);
 
-	request->header.type = ALFRED_REQUEST;
-	request->header.version = ALFRED_VERSION;
-	request->header.length = sizeof(*request) - sizeof(request->header);
-	request->header.length = htons(request->header.length);
-	request->requested_type = globals->clientmode_arg;
-	request->tx_id = get_random_id();
+	request.header.type = ALFRED_REQUEST;
+	request.header.version = ALFRED_VERSION;
+	request.header.length = FIXED_TLV_LEN(request);
+	request.requested_type = globals->clientmode_arg;
+	request.tx_id = get_random_id();
 
-	ret = write(globals->unix_sock, buf, len);
+	ret = write(globals->unix_sock, &request, len);
 	if (ret != len)
 		fprintf(stderr, "%s: only wrote %d of %d bytes: %s\n",
 			__func__, ret, len, strerror(errno));
@@ -179,26 +177,24 @@ int alfred_client_set_data(struct globals *globals)
 
 int alfred_client_modeswitch(struct globals *globals)
 {
-	unsigned char buf[MAX_PAYLOAD];
-	struct alfred_modeswitch_v0 *modeswitch;
+	struct alfred_modeswitch_v0 modeswitch;
 	int ret, len;
 
 	if (unix_sock_open_client(globals))
 		return -1;
 
-	modeswitch = (struct alfred_modeswitch_v0 *)buf;
-	len = sizeof(*modeswitch);
+	len = sizeof(modeswitch);
 
-	modeswitch->header.type = ALFRED_MODESWITCH;
-	modeswitch->header.version = ALFRED_VERSION;
-	modeswitch->header.length = htons(len - sizeof(modeswitch->header));
+	modeswitch.header.type = ALFRED_MODESWITCH;
+	modeswitch.header.version = ALFRED_VERSION;
+	modeswitch.header.length = FIXED_TLV_LEN(modeswitch);
 
 	switch (globals->opmode) {
 	case OPMODE_SECONDARY:
-		modeswitch->mode = ALFRED_MODESWITCH_SECONDARY;
+		modeswitch.mode = ALFRED_MODESWITCH_SECONDARY;
 		break;
 	case OPMODE_PRIMARY:
-		modeswitch->mode = ALFRED_MODESWITCH_PRIMARY;
+		modeswitch.mode = ALFRED_MODESWITCH_PRIMARY;
 		break;
 	default:
 		fprintf(stderr, "%s: unknown opmode %u in modeswitch\n",
@@ -206,7 +202,7 @@ int alfred_client_modeswitch(struct globals *globals)
 		return -1;
 	}
 
-	ret = write(globals->unix_sock, buf, len);
+	ret = write(globals->unix_sock, &modeswitch, len);
 	if (ret != len)
 		fprintf(stderr, "%s: only wrote %d of %d bytes: %s\n",
 			__func__, ret, len, strerror(errno));
@@ -248,8 +244,7 @@ static int check_interface(const char *iface)
 
 int alfred_client_change_interface(struct globals *globals)
 {
-	unsigned char buf[MAX_PAYLOAD];
-	struct alfred_change_interface_v0 *change_interface;
+	struct alfred_change_interface_v0 change_interface;
 	int ret, len;
 	char *input, *token, *saveptr;
 	size_t interface_len;
@@ -257,28 +252,27 @@ int alfred_client_change_interface(struct globals *globals)
 	if (unix_sock_open_client(globals))
 		return -1;
 
-	interface_len = strlen(globals->change_interface);
-	if (interface_len > sizeof(change_interface->ifaces)) {
+	interface_len = strlen(globals->net_iface);
+	if (interface_len > sizeof(change_interface.ifaces)) {
 		fprintf(stderr, "%s: interface name list too long, not changing\n",
 			__func__);
 		return 0;
 	}
 
-	change_interface = (struct alfred_change_interface_v0 *)buf;
-	len = sizeof(*change_interface);
+	len = sizeof(change_interface);
 
-	change_interface->header.type = ALFRED_CHANGE_INTERFACE;
-	change_interface->header.version = ALFRED_VERSION;
-	change_interface->header.length = htons(len - sizeof(change_interface->header));
-	strncpy(change_interface->ifaces, globals->change_interface,
-		sizeof(change_interface->ifaces));
-	change_interface->ifaces[sizeof(change_interface->ifaces) - 1] = '\0';
+	change_interface.header.type = ALFRED_CHANGE_INTERFACE;
+	change_interface.header.version = ALFRED_VERSION;
+	change_interface.header.length = FIXED_TLV_LEN(change_interface);
+	strncpy(change_interface.ifaces, globals->net_iface,
+		sizeof(change_interface.ifaces));
+	change_interface.ifaces[sizeof(change_interface.ifaces) - 1] = '\0';
 
 	/* test it before sending
-	 * globals->change_interface is now saved in change_interface->ifaces
+	 * globals->net_iface is now saved in change_interface.ifaces
 	 * and can be modified by strtok_r
 	 */
-	input = globals->change_interface;
+	input = globals->net_iface;
 	while ((token = strtok_r(input, ",", &saveptr))) {
 		input = NULL;
 
@@ -287,7 +281,42 @@ int alfred_client_change_interface(struct globals *globals)
 			return 0;
 	}
 
-	ret = write(globals->unix_sock, buf, len);
+	ret = write(globals->unix_sock, &change_interface, len);
+	if (ret != len)
+		fprintf(stderr, "%s: only wrote %d of %d bytes: %s\n",
+			__func__, ret, len, strerror(errno));
+
+	unix_sock_close(globals);
+
+	return 0;
+}
+
+int alfred_client_change_bat_iface(struct globals *globals)
+{
+	struct alfred_change_bat_iface_v0 change_bat_iface;
+	int ret, len;
+	size_t interface_len;
+
+	if (unix_sock_open_client(globals))
+		return -1;
+
+	interface_len = strlen(globals->mesh_iface);
+	if (interface_len > sizeof(change_bat_iface.bat_iface)) {
+		fprintf(stderr, "%s: batman-adv interface name list too long, not changing\n",
+			__func__);
+		return 0;
+	}
+
+	len = sizeof(change_bat_iface);
+
+	change_bat_iface.header.type = ALFRED_CHANGE_BAT_IFACE;
+	change_bat_iface.header.version = ALFRED_VERSION;
+	change_bat_iface.header.length = FIXED_TLV_LEN(change_bat_iface);
+	strncpy(change_bat_iface.bat_iface, globals->mesh_iface,
+		sizeof(change_bat_iface.bat_iface));
+	change_bat_iface.bat_iface[sizeof(change_bat_iface.bat_iface) - 1] = '\0';
+
+	ret = write(globals->unix_sock, &change_bat_iface, len);
 	if (ret != len)
 		fprintf(stderr, "%s: only wrote %d of %d bytes: %s\n",
 			__func__, ret, len, strerror(errno));
